####
linkhub.py
####
linkhub 1.0.2

링크인증 API for Python.

.. image:: https://api.travis-ci.org/linkhub-sdk/linkhub.py.svg?branch=master
        :target: https://travis-ci.org/linkhub-sdk/linkhub.py

* requirements

  * Python 2.6+

************
Installation
************

Install via pip:

::

    $ pip install linkhub

Install from source:

::

    $ git clone git://github.com/linkhub-sdk/linkhub.py.git
    $ cd linkhub.py
    $ python setup.py install
